#
# Conditional build:
%bcond_without	doc	# Sphinx documentation
%bcond_without	tests	# unit tests

%define		module	PyNaCl
Summary:	Python 2 binding to the Networking and Cryptography (NaCl) library
Summary(pl.UTF-8):	Wiązania Pythona 2 do biblioteki NaCl (Networking and Cryptography)
Name:		python3-%{module}
Version:	1.5.0
Release:	5
License:	Apache v2.0
Group:		Libraries/Python
Source0:	https://github.com/pyca/pynacl/archive/%{version}/pynacl-%{version}.tar.gz
# Source0-md5:	5f4332422b2be24fb1584eb447061b30
Patch0:		sphinx.patch
URL:		https://github.com/pyca/pynacl/
BuildRequires:	libsodium-devel >= 1.0.18
BuildRequires:	python3-cffi >= 1.4.1
BuildRequires:	python3-devel >= 1:3.6
BuildRequires:	python3-modules >= 1:3.6
BuildRequires:	python3-setuptools
%if %{with tests}
BuildRequires:	python3-hypothesis >= 3.27.0
BuildRequires:	python3-pytest >= 3.3.1
%endif
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%if %{with doc}
BuildRequires:	python3-sphinx_rtd_theme
BuildRequires:	sphinx-pdg-3 >= 1.6.5
%endif
Requires:	libsodium >= 1.0.18
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
PyNaCl is a Python binding to libsodium, which is a fork of the
Networking and Cryptography library.

%description -l pl.UTF-8
PyNaCl to wiązanie Pythona do libsodium - odgałęzienia biblioteki
NaCl (Networking and Cryptography).

%package apidocs
Summary:	API documentation for PyNaCl module
Summary(pl.UTF-8):	Dokumentacja API modułu PyNaCl
Group:		Documentation
BuildArch:	noarch

%description apidocs
API documentation for PyNaCl module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu PyNaCl.

%prep
%setup -q -n pynacl-%{version}
%patch -P0 -p1

%build
export SODIUM_INSTALL=system

%py3_build

%if %{with tests}
PYTHONPATH=$(echo $(pwd)/build-3/lib.*) \
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
%{__python3} -m pytest tests
%endif

%if %{with doc}
PYTHONPATH=$(echo $(pwd)/build-3/lib.*) \
%{__make} -C docs html \
	SPHINXBUILD=sphinx-build-3
%endif

%install
rm -rf $RPM_BUILD_ROOT

export SODIUM_INSTALL=system

%py3_install

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc CHANGELOG.rst README.rst
%dir %{py3_sitedir}/nacl
%attr(755,root,root) %{py3_sitedir}/nacl/_sodium.abi3.so
%{py3_sitedir}/nacl/py.typed
%{py3_sitedir}/nacl/*.py
%{py3_sitedir}/nacl/__pycache__
%{py3_sitedir}/nacl/bindings
%{py3_sitedir}/nacl/pwhash
%{py3_sitedir}/PyNaCl-%{version}-py*.egg-info

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/_build/html/{_downloads,_images,_modules,_static,api,vectors,*.html,*.js}
%endif
%changelog
* Wed May 28 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python3-PyNaCl.git;a=log;h=master

* Wed May 28 2025 Arkadiusz Miśkiewicz <arekm@maven.pl> e7e244f
- Release 5 (by relup.sh)

* Mon Apr 14 2025 Jan Rękorajski <baggins@pld-linux.org> 10a60c9
- rel 4, upstream shpinx fixes

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> fbbf164
- doc/test rebuild for python 3.13

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> c1f503b
- python 3.13 rebuild

* Sat Aug 12 2023 Jan Palus <atler@pld-linux.org> d3f513b
- correct url

* Sat Aug 12 2023 Jan Palus <atler@pld-linux.org> a4fe10c
- drop unused python2/python3 bconds

* Fri Oct 07 2022 Jakub Bogusz <qboosh@pld-linux.org> 7fcffcf
- noarch apidocs

* Wed Apr 27 2022 Jakub Bogusz <qboosh@pld-linux.org> 2600e18
- python-PyNaCl.spec updated to 1.5.0 for python 3.6+

* Wed Apr 27 2022 Jakub Bogusz <qboosh@pld-linux.org> af0522b
- python2 note

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 88c3272
- rebuild with tests and docs

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> 4be08e0
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 38ca209
- rebuild with python 3.10

* Sat Nov 20 2021 Jan Rękorajski <baggins@pld-linux.org> 216458f
- rebuild with separate debuginfo build-ids

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> aaabc4f
- release 2 (by relup.sh)

* Tue Feb 16 2021 Jakub Bogusz <qboosh@pld-linux.org> 2afa137
- updated to 1.4.0
- added no-wheel patch (don't require wheel to build)
- build apidocs

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> e682f15
- rebuild with python 3.8
- release 2 (by relup.sh)

* Sun Mar 31 2019 Jan Palus <atler@pld-linux.org> eded7ae
- new (version 1.3.0)

